import { ComputedRef } from 'vue-demi';

interface StopwatchOptions {
    /**
     * Start stopwatch as composable is called.
     * @default false
     */
    immediate?: boolean;
}
interface StopwatchReturn {
    /**
     * Pauses the stopwatch.
     */
    pause: () => void;
    /**
     * Resumes the stopwatch.
     */
    resume: () => void;
    /**
     * Resets the stopwatch to 0.
     */
    reset: () => void;
    /**
     * Whether the stopwatch is running or not.
     */
    running: ComputedRef<boolean>;
    /**
     * Time elapsed in milliseconds.
     */
    elapsed: ComputedRef<number>;
}
/**
 * Stopwatch persisted in storage.
 * @param key Key to reference the stopwatch in storage.
 * @param options
 */
declare function useStopwatch(key: string, options?: StopwatchOptions): StopwatchReturn;

export default useStopwatch;
export { StopwatchOptions, StopwatchReturn };
